==> symbol.equation.gpt_1.1.3.tar.gz: symbol.equation.gpt/README.md <==
# symbol.equation.gpt R package: Powerful user interface to build equations and insert symbols in R documents such as Rmarkdown or Quarto or Shiny applications.<img src="https://symbols-ui.obi.obianom.com/logo.png" align="right" width="200">

### Official website: https://symbols-ui.obi.obianom.com

### Explainer video: https://www.youtube.com/watch?v=cm6FDzO2uqI

[![CRAN\_Status\_Badge](https://img.shields.io/badge/RPKG-published-orange)](https://rpkg.net/package/symbol.equation.gpt) <img src="https://rpkg.net/pub-age/symbol.equation.gpt"> [![CRAN\_Status\_Badge](https://www.r-pkg.org/badges/version/symbol.equation.gpt)](https://cran.r-project.org/package=symbol.equation.gpt) [![](https://cranlogs.r-pkg.org/badges/symbol.equation.gpt)](https://cran.r-project.org/package=symbol.equation.gpt) [![](https://cranlogs.r-pkg.org/badges/grand-total/symbol.equation.gpt)](https://cran.r-project.org/package=symbol.equation.gpt)
[![symbol.equation.gpt pkg](https://rpkg.net/rpkg/symbol.equation.gpt/brown)](https://rpkg.net/package/symbol.equation.gpt)


## Quick example in R 

First, install and load...

```
install.packages("symbol.equation.gpt")

library("symbol.equation.gpt")

# Launch 1: from Addins

# Go to "Addins" in RStudio, and click on "Symbols and Equations"

# Launch 2: from console

symbol.equation.ui()

# Launch 3: from console

symbol.equation.ui2()

```

#### Live sample 1

![](https://symbols-ui.obi.obianom.com/vids/SYMBOLS.EQUATIONS.OPEN3.gif)

#### Live sample 2

![](https://symbols-ui.obi.obianom.com/vids/SYMBOLS.EQUATIONS.OPEN2.gif)


### Launch User Interface from RStudio Addins

#### User Interface Screenshot - equations

![](https://symbols-ui.obi.obianom.com/assets/equationrpkg1.png)


#### User Interface Screenshot - symbols

![](https://symbols-ui.obi.obianom.com/assets/equationrpkg3.png)

#### User Interface Screenshot - smiley

![](https://symbols-ui.obi.obianom.com/assets/equationrpkg2.png)






# Use on the Web

Available for use online as well  - https://equations.rpkg.net/

==> symbol.equation.gpt_1.1.4.tar.gz: symbol.equation.gpt/README.md <==
# symbol.equation.gpt v1.1.4 is finally here!

Let's make the equation builder great again!

## symbol.equation.gpt R package: Powerful user interface to build equations and insert symbols in R documents such as Rmarkdown or Quarto or Shiny applications.<img src="https://symbols-ui.obi.obianom.com/logo.png" align="right" width="200">

### Official website: https://symbols-ui.obi.obianom.com

### Explainer video: https://www.youtube.com/watch?v=cm6FDzO2uqI

[![CRAN\_Status\_Badge](https://img.shields.io/badge/RPKG-published-orange)](https://rpkg.net/package/symbol.equation.gpt) <img src="https://rpkg.net/pub-age/symbol.equation.gpt"> [![CRAN\_Status\_Badge](https://www.r-pkg.org/badges/version/symbol.equation.gpt)](https://cran.r-project.org/package=symbol.equation.gpt) [![](https://cranlogs.r-pkg.org/badges/symbol.equation.gpt)](https://cran.r-project.org/package=symbol.equation.gpt) [![](https://cranlogs.r-pkg.org/badges/grand-total/symbol.equation.gpt)](https://cran.r-project.org/package=symbol.equation.gpt)
[![symbol.equation.gpt pkg](https://rpkg.net/rpkg/symbol.equation.gpt/yellow)](https://rpkg.net/package/symbol.equation.gpt)


## Quick example in R 

First, install and load...

```
install.packages("symbol.equation.gpt")

library("symbol.equation.gpt")

# Launch 1: from Addins

# Go to "Addins" in RStudio, and click on "Symbols and Equations"

# Launch 2: from console

symbol.equation.ui()

# Launch 3: from console

symbol.equation.ui2()

```

#### Live sample 1

![](https://symbols-ui.obi.obianom.com/vids/SYMBOLS.EQUATIONS.OPEN3.gif)

#### Live sample 2

![](https://symbols-ui.obi.obianom.com/vids/SYMBOLS.EQUATIONS.OPEN2.gif)


### Launch User Interface from RStudio Addins

#### User Interface Screenshot - equations

![](https://symbols-ui.obi.obianom.com/assets/equationrpkg1.png)


#### User Interface Screenshot - symbols

![](https://symbols-ui.obi.obianom.com/assets/equationrpkg3.png)

#### User Interface Screenshot - smiley

![](https://symbols-ui.obi.obianom.com/assets/equationrpkg2.png)






# Use on the Web

Available for use online as well  - https://equations.rpkg.net/
